/**
 * @Copyright (c) Microsoft Corporation.  All rights reserved.
 */
/**
 * This interface defines members that are common between all deployable manifests.
 *
 * @public
 */
export interface IClientSideManifestBase {
    /**
     * Definition: Version of the component manifest schema. The value of this field is controlled by Microsoft. The
     *  purpose of this field is to help manage upgrades of the component manifest schema. A component developer needs to
     *  only confirm that they are using the correct value per the manifest schema. Please read the "manifest upgrade
     *  rules" for more details on when the schema could change. Note, manifest schema version upgrade will be considered
     *  a big API change event and will be advertised broadly.
     * Usage: To help support multiple manifest schema versions.
     * Required: yes
     * Localized: no
     * Supported values: Positive integer.
     * Example: 1
     */
    manifestVersion: number;
    /**
     * Definition: A universally unique component id. Each client side component is required to have this id. Once an
     *  id has been used for a component, it cannot be changed. A change in this value is treated same as the creation of
     *  a new component. Two components are never expected to have the same id.
     * Usage: Uniquely identify a client side component.
     * Required: yes
     * Localized: no
     * Supported values: any GUID
     * Example: "dbef608d-3ad5-4f8f-b139-d916f2f0a294"
     */
    id: string;
}
